@@ -10,11 +10,11 @@ CPAN::AuthorsSearch - Interface to CPAN module author search.
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 our $DEBUG   = 0;
 
 use Carp;
@@ -23,11 +23,11 @@ use HTTP::Request;
 use LWP::UserAgent;
 use HTML::Entities qw/decode_entities/;
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
-CPAN::AuthorsSearch is an attempt to provide a programmatical interface to CPAN Search engine. 
-CPAN Search is a search engine for the distributions, modules, docs, and ID's on CPAN. It was 
-conceived  and  built by  Graham Barr  as a way to make things easier to navigate. Originally 
+CPAN::AuthorsSearch is an attempt to provide a programmatical interface to CPAN Search engine.
+CPAN Search is a search engine for the distributions, modules, docs, and ID's on CPAN.  It was
+conceived  and  built by  Graham Barr  as a way to make things easier to navigate.  Originally
 named TUCS [ The Ultimate CPAN Search ] it was later named CPAN Search or Search DOT CPAN.
 
 =cut
@@ -36,7 +36,7 @@ sub new
 {
     my $class = shift;
     my $self  = { _browser => LWP::UserAgent->new() };
-    
+
     bless $self, $class;
     return $self;
 }
@@ -45,9 +45,9 @@ sub new
 
 =head2 by_id()
 
-This method accepts CPAN ID exactly as provided by CPAN. It does realtime search on CPAN site and  fetch
-the author name for the given CPAN ID. However it would croak if it can't access the CPAN site or unable 
-to get any response for the given CPAN ID.
+This method accepts CPAN ID exactly as provided by CPAN. It does realtime search on  CPAN site
+and fetch the author name for the given CPAN ID. However it would croak if it can't access the
+CPAN site or unable to get any response for the given CPAN ID.
 
     use strict; use warnings;
     use CPAN::AuthorsSearch;
@@ -60,14 +60,14 @@ sub by_id
 {
     my $self     = shift;
     my $id       = shift;
-    
+
     my $browser  = $self->{_browser};
     my $request  = HTTP::Request->new(POST=>qq[http://search.cpan.org/search?query=$id&mode=author]);
     my $response = $browser->request($request);
     print {*STDOUT} "Search By Id [$id] Status: " . $response->status_line . "\n" if $DEBUG;
     croak("ERROR: Couldn't connect to search.cpan.org.\n") 
         unless $response->is_success;
-    
+
     my $contents = $response->content;
     my @contents = split(/\n/,$contents);
     foreach (@contents)
@@ -90,8 +90,8 @@ sub by_id
 
 =head2 where_id_starts_with()
 
-This method accepts an alphabet (A-Z) and get the list of authors that start with the  given
-alphabet from CPAN site realtime. However it would croak if it can't access the CPAN site or 
+This  method  accepts an alphabet (A-Z) and get the list of authors that start with the  given
+alphabet  from  CPAN site realtime. However it would croak if it can't access the CPAN site or
 unable to get any response for the given CPAN ID.
 
     use strict; use warnings;
@@ -107,17 +107,17 @@ sub where_id_starts_with
     my $letter = shift;
     croak("ERROR: Invalid letter [$letter].\n")
         unless ($letter =~ /[A-Z]/i);
-        
+
     my $browser  = $self->{_browser};
     my $request  = HTTP::Request->new(POST=>qq[http://search.cpan.org/author/?$letter]);
     my $response = $browser->request($request);
     print {*STDOUT} "Search Id Starts With [$letter] Status: " . $response->status_line . "\n" if $DEBUG;
     croak("ERROR: Couldn't connect to search.cpan.org.\n") 
         unless $response->is_success;
-    
+
     my $contents = $response->content;
     my @contents = split(/\n/,$contents);
-    
+
     my @authors;
     foreach (@contents)
     {
@@ -134,9 +134,9 @@ sub where_id_starts_with
 
 =head2 where_name_contains()
 
-This method accepts a search string and look for the string in the author's name of all the CPAN modules
-realtime and returns the a reference to a hash containing id, name pair containing the search string. It
-croaks if unable to access the search.cpan.org.
+This  method  accepts  a search string and look for the string in the author's name of all the
+CPAN modules realtime and returns the a reference to a hash containing id,name pair containing
+the search string. It croaks if unable to access the search.cpan.org.
 
     use strict; use warnings;
     use CPAN::AuthorsSearch;
@@ -149,17 +149,17 @@ sub where_name_contains
 {
     my $self     = shift;
     my $query    = shift;
-    
+
     my $browser  = $self->{_browser};
     my $request  = HTTP::Request->new(POST=>qq[http://search.cpan.org/search?query=$query&mode=author]);
     my $response = $browser->request($request);
     print {*STDOUT} "Search By Name Contains [$query] Status: " . $response->status_line . "\n" if $DEBUG;
     croak("ERROR: Couldn't connect to search.cpan.org.\n") 
         unless $response->is_success;
-    
+
     my $contents = $response->content;
     my @contents = split(/\n/,$contents);
-    
+
     my $authors;
     foreach (@contents)
     {
@@ -184,10 +184,10 @@ Return the last search result in human readable format.
     my $search = CPAN::AuthorsSearch->new();
     my $result = $search->where_name_contains('MAN');
     print $search->as_string();
-	
-	# or simply
-	
-	print $search;
+
+    # or simply
+    
+    print $search;
 
 =cut
 
@@ -195,7 +195,7 @@ sub as_string
 {
     my $self = shift;
     return $self->{result} unless ref($self->{result});
-    
+
     my $string;
     foreach (keys %{$self->{result}})
     {
@@ -210,9 +210,10 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 BUGS
 
-Please  report any bugs or feature requests to C<bug-cpan-authorssearch at rt.cpan.org>,  or through the 
-web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CPAN-AuthorsSearch>.I will be notified, 
-and then you'll automatically be notified of progress on your bug as I make changes.
+Please   report  any bugs or feature requests to C<bug-cpan-authorssearch at rt.cpan.org>,  or
+through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CPAN-AuthorsSearch>.
+I  will  be  notified,  and then you'll automatically be notified of progress on your bug as I
+make changes.
 
 =head1 SUPPORT
 
@@ -246,15 +247,16 @@ L<http://search.cpan.org/dist/CPAN-AuthorSearch/>
 
 Copyright 2011 Mohammad S Anwar.
 
-This  program  is free software; you can redistribute it and/or modify it under the terms of either: the 
-GNU General Public License as published by the Free Software Foundation; or the Artistic License.
+This  program   is free software; you can redistribute it and/or modify  it under the terms of
+either :  the  GNU General Public License as published by the Free Software Foundation; or the
+Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
 =head1 DISCLAIMER
 
-This program  is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;  without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+This  program   is  distributed in the hope that it will be useful, but WITHOUT  ANY WARRANTY;
+without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 =cut
 
